Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorCampbell Barton <ideasman42@gmail.com>2013-04-16 09:59:48 +0400
committerCampbell Barton <ideasman42@gmail.com>2013-04-16 09:59:48 +0400
commit37e73aa368d7f3cd855fab0812673b484ee4f4e9 (patch)
tree31e960dafb0e5a8034b2f31e6e6e33b5828ea30e /source/blender/blenkernel/BKE_editmesh_bvh.h
parent77da6b3662847c78c867b488d2fae0f37aabdf7b (diff)
code cleanup: use BKE naming conventions for functions in BKE_editmesh.h and BKE_editmesh_bvh.h
Diffstat (limited to 'source/blender/blenkernel/BKE_editmesh_bvh.h')
-rw-r--r--source/blender/blenkernel/BKE_editmesh_bvh.h21
1 files changed, 8 insertions, 13 deletions
diff --git a/source/blender/blenkernel/BKE_editmesh_bvh.h b/source/blender/blenkernel/BKE_editmesh_bvh.h
index edf261da6e8..cdab48f239c 100644
--- a/source/blender/blenkernel/BKE_editmesh_bvh.h
+++ b/source/blender/blenkernel/BKE_editmesh_bvh.h
@@ -34,27 +34,22 @@
struct BMEditMesh;
struct BMFace;
-struct BMEdge;
struct BMVert;
-struct RegionView3D;
struct BMBVHTree;
struct BVHTree;
struct Scene;
-struct Object;
typedef struct BMBVHTree BMBVHTree;
-BMBVHTree *BMBVH_NewBVH(struct BMEditMesh *em, int flag, struct Scene *scene);
-void BMBVH_FreeBVH(BMBVHTree *tree);
-struct BVHTree *BMBVH_BVHTree(BMBVHTree *tree);
+BMBVHTree *BKE_bmbvh_new(struct BMEditMesh *em, int flag, struct Scene *scene);
+void BKE_bmbvh_free(BMBVHTree *tree);
+struct BVHTree *BKE_bmbvh_tree_get(BMBVHTree *tree);
+struct BMFace *BKE_bmbvh_ray_cast(BMBVHTree *tree, const float co[3], const float dir[3],
+ float r_hitout[3], float r_cagehit[3]);
+/* find a vert closest to co in a sphere of radius maxdist */
+struct BMVert *BKE_bmbvh_find_vert_closest(BMBVHTree *tree, const float co[3], const float maxdist);
-struct BMFace *BMBVH_RayCast(BMBVHTree *tree, const float co[3], const float dir[3],
- float r_hitout[3], float r_cagehit[3]);
-
-/*find a vert closest to co in a sphere of radius maxdist*/
-struct BMVert *BMBVH_FindClosestVert(BMBVHTree *tree, const float co[3], const float maxdist);
-
-/* BMBVH_NewBVH flag parameter */
+/* BKE_bmbvh_new flag parameter */
enum {
BMBVH_USE_CAGE = 1, /* project geometry onto modifier cage */
BMBVH_RETURN_ORIG = 2, /* use with BMBVH_USE_CAGE, returns hits in relation to original geometry */